<?php
/*
Plugin Name: WooCommerce Email Account Check (EasyToolsWP)
Description: Shows a popup to log in if a customer already has an account.
Version: 1.0
Author: EasyToolsWP.com
*/

// Enqueue JavaScript file and CSS
function enqueue_login_popup_script() {
    if (!is_user_logged_in()) {
        wp_enqueue_style('login-popup-style', plugins_url('/css/login-popup.css', __FILE__));
        wp_enqueue_script('login-popup-script', plugins_url('/js/login-popup.js', __FILE__), array('jquery'), null, true);

        wp_localize_script('login-popup-script', 'wc_checkout_params', array(
            'ajax_url' => admin_url('admin-ajax.php')
        ));
    }
}
add_action('wp_enqueue_scripts', 'enqueue_login_popup_script');

// Create AJAX handler for email check
function check_user_email() {
    if (isset($_POST['email'])) {
        $email = sanitize_email($_POST['email']);
        $user = get_user_by('email', $email);

        if ($user) {
            wp_send_json_success(array('exists' => true));
        } else {
            wp_send_json_success(array('exists' => false));
        }
    }

    wp_send_json_error();
}
add_action('wp_ajax_check_user_email', 'check_user_email');
add_action('wp_ajax_nopriv_check_user_email', 'check_user_email');

// Handle AJAX login
function ajax_login() {
    if (isset($_POST['log']) && isset($_POST['pwd'])) {
        $creds = array(
            'user_login'    => sanitize_text_field($_POST['log']),
            'user_password' => sanitize_text_field($_POST['pwd']),
            'remember'      => isset($_POST['rememberme']) ? true : false,
        );

        $user = wp_signon($creds, false);

        if (is_wp_error($user)) {
            $error_message = '<strong>Error:</strong> ' . $user->get_error_message();
            wp_send_json_error(array('message' => $error_message));
        } else {
            wp_send_json_success(array('redirect_url' => wc_get_checkout_url()));
        }
    }

    wp_send_json_error(array('message' => 'Invalid request.'));
}
add_action('wp_ajax_nopriv_ajax_login', 'ajax_login');

// Add settings page to the admin menu
function add_settings_menu() {
    add_options_page(
        'Popup Settings',
        'Popup Settings',
        'manage_options',
        'popup-settings',
        'popup_settings_page'
    );
}
add_action('admin_menu', 'add_settings_menu');

// Display the settings page
function popup_settings_page() {
    ?>
    <div class="wrap">
        <h1>Popup Settings</h1>
        <form method="post" action="options.php">
            <?php
            settings_fields('popup_settings_group');
            do_settings_sections('popup-settings');
            submit_button();
            ?>
        </form>
    </div>
    <?php
}

// Register settings
function register_popup_settings() {
    register_setting('popup_settings_group', 'popup_settings');

    add_settings_section(
        'popup_settings_section',
        'Popup Text Translations',
        null,
        'popup-settings'
    );

    add_settings_field(
        'popup_message',
        'Popup Message',
        'popup_message_field',
        'popup-settings',
        'popup_settings_section'
    );
    add_settings_field(
        'login_failed_message',
        'Login Failed Message',
        'login_failed_message_field',
        'popup-settings',
        'popup_settings_section'
    );
    add_settings_field(
        'username_placeholder',
        'Username Placeholder',
        'username_placeholder_field',
        'popup-settings',
        'popup_settings_section'
    );
    add_settings_field(
        'password_placeholder',
        'Password Placeholder',
        'password_placeholder_field',
        'popup-settings',
        'popup_settings_section'
    );
    add_settings_field(
        'remember_me_label',
        'Remember Me Label',
        'remember_me_label_field',
        'popup-settings',
        'popup_settings_section'
    );
    add_settings_field(
        'login_button_label',
        'Login Button Label',
        'login_button_label_field',
        'popup-settings',
        'popup_settings_section'
    );
    add_settings_field(
        'continue_as_guest_label',
        'Continue as Guest Label',
        'continue_as_guest_label_field',
        'popup-settings',
        'popup_settings_section'
    );
}
add_action('admin_init', 'register_popup_settings');

// Field callbacks
function popup_message_field() {
    $options = get_option('popup_settings');
    $default_text = 'You already have an account. Would you like to log in before continuing?';
    echo '<input type="text" name="popup_settings[popup_message]" value="' . esc_attr($options['popup_message'] ?? $default_text) . '" />';
}

function login_failed_message_field() {
    $options = get_option('popup_settings');
    $default_text = 'Login failed: Error: The username field is empty.';
    echo '<input type="text" name="popup_settings[login_failed_message]" value="' . esc_attr($options['login_failed_message'] ?? $default_text) . '" />';
}

function username_placeholder_field() {
    $options = get_option('popup_settings');
    $default_text = 'Username or Email Address';
    echo '<input type="text" name="popup_settings[username_placeholder]" value="' . esc_attr($options['username_placeholder'] ?? $default_text) . '" />';
}

function password_placeholder_field() {
    $options = get_option('popup_settings');
    $default_text = 'Password';
    echo '<input type="text" name="popup_settings[password_placeholder]" value="' . esc_attr($options['password_placeholder'] ?? $default_text) . '" />';
}

function remember_me_label_field() {
    $options = get_option('popup_settings');
    $default_text = 'Remember Me';
    echo '<input type="text" name="popup_settings[remember_me_label]" value="' . esc_attr($options['remember_me_label'] ?? $default_text) . '" />';
}

function login_button_label_field() {
    $options = get_option('popup_settings');
    $default_text = 'Login';
    echo '<input type="text" name="popup_settings[login_button_label]" value="' . esc_attr($options['login_button_label'] ?? $default_text) . '" />';
}

function continue_as_guest_label_field() {
    $options = get_option('popup_settings');
    $default_text = 'Continue as guest?';
    echo '<input type="text" name="popup_settings[continue_as_guest_label]" value="' . esc_attr($options['continue_as_guest_label'] ?? $default_text) . '" />';
}

// Add popup HTML to the checkout page
function add_login_popup_html() {
    if (!is_user_logged_in()) {
        $options = get_option('popup_settings');
        $popup_message = esc_html($options['popup_message'] ?? 'You already have an account. Would you like to log in before continuing?');
        $login_failed_message = esc_html($options['login_failed_message'] ?? 'Login failed: The username field is empty.');
        $username_placeholder = esc_html($options['username_placeholder'] ?? 'Email Address');
        $password_placeholder = esc_html($options['password_placeholder'] ?? 'Password');
        $remember_me_label = esc_html($options['remember_me_label'] ?? 'Remember Me');
        $login_button_label = esc_html($options['login_button_label'] ?? 'Login');
        $continue_as_guest_label = esc_html($options['continue_as_guest_label'] ?? 'Continue as guest?');
        ?>
        <div id="login-popup" style="display:none;">
            <div class="popup-content">
                <p><?php echo $popup_message; ?></p>
                <button id="continue-as-guest"><?php echo $continue_as_guest_label; ?></button>
                <button id="login-button"><?php echo $login_button_label; ?></button>
                <div id="login-form" style="display:none;">
                    <div id="error-message" style="color: #c72222; display: none;"></div>
                    <?php
                    $args = array(
                        'echo'           => false,
                        'redirect'       => wc_get_checkout_url(),
                        'form_id'        => 'ajax-login-form',
                        'label_username' => $username_placeholder,
                        'label_password' => $password_placeholder,
                        'label_remember' => $remember_me_label,
                        'value_remember' => true,
                        'remember'       => true
                    );
                    echo wp_login_form($args);
                    ?>
                </div>
            </div>
        </div>
        <?php
    }
}
add_action('wp_footer', 'add_login_popup_html');

// Redirect after login based on success or failure
function custom_login_redirect($redirect_to, $request, $user) {
    return wc_get_checkout_url(); // Redirect to checkout
}
add_filter('login_redirect', 'custom_login_redirect', 10, 3);
